@@ -12,14 +12,13 @@ f = function(x) #only the first 5 matter
 sigma = 1.0  #y = f(x) + sigma*z where z~N(0, 1)
 P = 100      #number of covariates
 C = 8
-thin <- c(10, 50, 250)
-
-par(mfrow=c(3, 1))
+thin <- c(10, 10, 10)
+n <- c(200, 1000, 5000)
 
 post <- as.list(1:3)
 
 for(i in 1:3) {
-    N <- 10^(1+i)
+    N <- n[i]
     set.seed(12)
     x.train=matrix(runif(N*P), N, P)
     Ey.train = f(x.train)
@@ -27,10 +26,15 @@ for(i in 1:3) {
 
     post[[i]] = mc.pbart(x.train, y.train, mc.cores=C,
                          keepevery=thin[i], sparse=TRUE, seed=99)
+}
 
+par(mfrow=c(3, 1))
+
+for(i in 1:3) {
+    N <- n[i]
     plot(post[[i]]$varprob.mean, col=c(rep(2, 5), rep(1, P-5)),
          main=paste0('N:', N, ', P:', P, ', thin:', thin[i]),
-         ylab='Selection Probability', ylim=c(0, 0.2),
+         ylab='Selection Probability', ylim=c(0, 0.3),
          pch=1+45*(post[[i]]$varprob.mean <= 1/P))
     lines(c(0, 100), c(1/P, 1/P))
 
